cgexplore.molecular
===================

.. automodule:: cgexplore.molecular

   
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: class.rst
      :nosignatures:
   
      BeadLibrary
      CgBead
      Conformer
      Ensemble
      FourC0Arm
      FourC1Arm
      GeneratedPrecursor
      LinearPrecursor
      Precursor
      PrecursorGenerator
      SpindryConformer
      SquarePrecursor
      ThreeC0Arm
      ThreeC1Arm
      ThreeC2Arm
      Timestep
      TrianglePrecursor
      TwoC0Arm
      TwoC1Arm
      TwoC2Arm
      TwoC3Arm
      VaBene
      VaBeneGenerator
   
   


   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
      :nosignatures:
   
      check_fit
      periodic_table
      spd_to_stk
      string_to_atom_number
   
   

   
   
   



